
from django.utils.translation import ugettext_lazy as _

from cms.plugin_pool import plugin_pool
from djangocms_style.cms_plugins import StylePlugin

from . import models


class ListStylePlugin(StylePlugin):
    model = models.ListStyle
    name = 'List'
    render_template = 'djangocms_listyle/index.html'

    fieldsets = (
        (None, {
            'fields': (
                'label',
                'list_type',
            )
        }),
        (_('Advanced settings'), {
            'classes': ('collapse',),
            'fields': (
                'additional_classes',
                'id_name',
                'template',
                'attributes',
            ),
        }),
        (_('Inline style settings'), {
            'classes': ('collapse',),
            'fields': (
                ('padding_top', 'padding_right',
                 'padding_bottom', 'padding_left'),
                ('margin_top', 'margin_right',
                 'margin_bottom', 'margin_left'),
            ),
        }),
    )

    def get_render_template(self, context, instance, placeholder):
        return 'djangocms_listyle/index.html'.format(instance.template)


plugin_pool.register_plugin(ListStylePlugin)




from django.db import models
from django.utils.encoding import python_2_unicode_compatible

from djangocms_style.models import Style

OL = 'ol'
UL = 'ul'
LIST_TYPE_CHOICES = (
    (OL, 'Ordered'),
    (UL, 'Unordered'),
)


@python_2_unicode_compatible
class ListStyle(Style):
    list_type = models.CharField(
        max_length=2,
        choices=LIST_TYPE_CHOICES,
        default=UL,
    )

    def get_short_description(self):
        # display format:
        # Style label <tag> .list.of.classes #id
        display = []
        classes = []

        if self.label:
            display.append(self.label)
        if self.list_type:
            display.append('<{0}>'.format(self.list_type))
        if self.additional_classes:
            classes.extend(x.strip() for x in self.additional_classes.split(',') if x.strip())
        display.append('.{0}'.format('.'.join(classes)))
        if self.id_name:
            display.append('#{0}'.format(self.id_name))
        return ' '.join(display)




import os
from setuptools import setup, find_packages


def read(filename):
    return open(os.path.join(os.path.dirname(__file__), filename)).read()

def readlines(filename):
    with open(os.path.join(os.path.dirname(__file__), filename)) as open_file:
        return [l.split("==")[0] for l in open_file.readlines()]


CLASSIFIERS = [
    'Development Status :: 4 - Beta',
    'Environment :: Web Environment',
    'Framework :: Django',
    'Intended Audience :: Developers',
    'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
    'Operating System :: OS Independent',
    'Programming Language :: Python',
    'Topic :: Internet :: WWW/HTTP',
    'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    'Topic :: Software Development :: Libraries :: Application Frameworks',
    'Topic :: Software Development :: Libraries :: Python Modules',
]


setup(
    name='djangocms-listyle',
    version='0.1',
    author='Ben Miller',
    author_email='mail@benkmiller.com',
    description='Adds a plugin to embed an ordered or unordered list to django CMS. Children are automatically wrapped in <li> tags.',
    license='GNU General Public License v3 (GPLv3), see LICENSE.md',
    url='https://github.com/djangocms-listyle',
    packages=find_packages(exclude=["tests"]),
    long_description=read('README.md'),
    install_requires=readlines('requirements/production.txt'),
    classifiers=CLASSIFIERS,
)
